@@ -144,7 +144,7 @@ def run_tests():
 
     print("Warning: if you are in a Jupyter notebook you will not see output until the tests complete.")
     print("Use the terminal to view periodic progress...")
-    subprocess.check_call(get_local_bash() + ['tests/test_all.sh'])
+    subprocess.check_call(get_local_bash() + ['tests/test_all.sh', this_python])
     print("Completed tests successfully.")
 
 
@@ -196,9 +196,11 @@ def compile_rules(*rules, **kwargs):
             g_stdout, g_stderr = po.communicate()
             status = po.returncode
 
-            if (status != 0):
+            if kwargs.get('compiler_output', (status != 0)):
                 sys.stderr.write("Compiler stdout: %s\n" % g_stdout)
                 sys.stderr.write("Compiler stderr: %s\n" % g_stderr)
+
+            if (status != 0):
                 raise RuntimeError("g++ returned nonzero exit code %d" % status)
 
         finally:
