@@ -14,6 +14,12 @@ class TestGoL(unittest.TestCase):
         self.sess = lifelib.load_rules('b3s23')
         self.lt = self.sess.lifetree(memory=1000, n_layers=4)
 
+    def test_hashsoup(self):
+
+        x = self.lt.hashsoup("b3s23", "C1", "n_GcpqZ62YqD3310086454")
+        ac = x[1000].apgcode
+        self.assertEqual(ac, 'xp46_033y133zzzckgsxsgkczydciczy4ccy0222')
+
     def test_lhistory(self):
 
         scorbie = self.lt.pattern('''x = 50, y = 72, rule = LifeHistory
